==> jtharness_5.0.orig.tar.xz: jtharness-5.0/src/com/sun/interview/wizard/SwingFileFilter.java <==
/*
 * $Id$
 *
 * Copyright (c) 2002, 2009, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.interview.wizard;

import java.io.File;

import com.sun.interview.FileFilter;

class SwingFileFilter extends javax.swing.filechooser.FileFilter
{
    static javax.swing.filechooser.FileFilter wrap(FileFilter f) {
        return new SwingFileFilter(f);
    }

    static FileFilter unwrap(javax.swing.filechooser.FileFilter f) {
        if (f != null && f instanceof SwingFileFilter)
            return (((SwingFileFilter)f).filter);
        else
            return null;
    }

    SwingFileFilter(FileFilter ff) {
        if (ff == null)
            throw new NullPointerException();
        filter = ff;
    }

    public boolean accept(File f) {
        return f.isDirectory() || filter.accept(f);
    }

    public String getDescription() {
        return filter.getDescription();
    }

    FileFilter filter;
}

==> jtharness_6.0-b15.orig.tar.xz: jtharness-6.0-b15/src/com/sun/interview/wizard/SwingFileFilter.java <==
/*
 * $Id$
 *
 * Copyright (c) 2002, 2009, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.interview.wizard;

import com.sun.interview.FileFilter;

import java.io.File;

class SwingFileFilter extends javax.swing.filechooser.FileFilter {
    FileFilter filter;

    SwingFileFilter(FileFilter ff) {
        if (ff == null) {
            throw new NullPointerException();
        }
        filter = ff;
    }

    static javax.swing.filechooser.FileFilter wrap(FileFilter f) {
        return new SwingFileFilter(f);
    }

    static FileFilter unwrap(javax.swing.filechooser.FileFilter f) {
        if (f != null && f instanceof SwingFileFilter) {
            return ((SwingFileFilter) f).filter;
        } else {
            return null;
        }
    }

    @Override
    public boolean accept(File f) {
        return f.isDirectory() || filter.accept(f);
    }

    @Override
    public String getDescription() {
        return filter.getDescription();
    }
}
